@@ -16,8 +16,10 @@ from emannotationschemas.schemas.base import FlatSegmentationReferenceSinglePoin
 from emannotationschemas.schemas.cell_type_local import CellTypeLocal, CellTypeReference
 from emannotationschemas.schemas.bound_text_tag import (
     BoundTagAnnotation,
+    BoundDoubleTagAnnotation,
     Bound2TagAnnotation,
     BoundTagAnnotationUser,
+    BoundDoubleTagAnnotationUser,
     Bound2TagAnnotationUser,
 )
 from emannotationschemas.schemas.glia_contact import GliaContact
@@ -37,11 +39,13 @@ from emannotationschemas.schemas.proofreading import (
     ProofreadingBoolStatusUser,
 )
 from emannotationschemas.schemas.neuropil import FlyNeuropil
+from emannotationschemas.schemas.groups import SimpleGroup
+from emannotationschemas.schemas.fly_cell_types import FlyCellType, FlyCellTypeExt
 
 from emannotationschemas.errors import UnknownAnnotationTypeException
 from emannotationschemas.flatten import create_flattened_schema
 
-__version__ = "4.1.1"
+__version__ = "5.0.2"
 
 type_mapping = {
     "synapse": SynapseSchema,
@@ -58,8 +62,10 @@ type_mapping = {
     "cell_type_reference": CellTypeReference,
     "nucleus_detection": NucleusDetection,
     "bound_tag": BoundTagAnnotation,
+    "bound_double_tag": BoundDoubleTagAnnotation,
     "bound_2tag": Bound2TagAnnotation,
     "bound_tag_user": BoundTagAnnotationUser,
+    "bound_double_tag_user": BoundDoubleTagAnnotationUser,
     "bound_2tag_user": Bound2TagAnnotationUser,
     "extended_classical_cell_type": ExtendedClassicalCellType,
     "plastic_synapse": PlasticSynapse,
@@ -74,6 +80,9 @@ type_mapping = {
     "fly_neuropil": FlyNeuropil,
     "reference_point": FlatSegmentationReferenceSinglePoint,
     "reference_synapse_valid": ValidSynapse,
+    "reference_simple_group": SimpleGroup,
+    "fly_cell_type": FlyCellType,
+    "fly_cell_type_ext": FlyCellTypeExt,
 }
 
 
@@ -110,56 +119,7 @@ def get_schema(schema_type: str):
 def get_flat_schema(schema_type: str):
     try:
         Schema = type_mapping[schema_type]
-        FlatSchema = create_flattened_schema(Schema)
-        return FlatSchema
-    except KeyError:
-        msg = f"Schema type: {schema_type} is not a known annotation type"
+        return create_flattened_schema(Schema)
+    except KeyError as e:
+        msg = f"Schema type: {schema_type} is not a known annotation type: {e}"
         raise UnknownAnnotationTypeException(msg)
-
-
-def create_app(test_config=None):
-    from flask import Flask, jsonify, url_for, redirect, Blueprint
-    from flask_restx import Api
-
-    from emannotationschemas.config import configure_app
-    from emannotationschemas.utils import get_instance_folder_path
-
-    from emannotationschemas.blueprint_app import api_bp
-    from emannotationschemas.views import views_bp
-    import logging
-
-    # Define the Flask Object
-    app = Flask(
-        __name__,
-        instance_path=get_instance_folder_path(),
-        static_url_path="/schema/static",
-        instance_relative_config=True,
-    )
-
-    logging.basicConfig(level=logging.DEBUG)
-
-    # load configuration (from test_config if passed)
-    if test_config is None:
-        app = configure_app(app)
-    else:
-        app.config.update(test_config)
-
-    apibp = Blueprint("api", __name__, url_prefix="/schema/api")
-
-    @app.route("/schema/versions")
-    def versions():
-        return jsonify([2]), 200
-
-    @app.route("/schema/")
-    def index():
-        return redirect("/schema/views")
-
-    with app.app_context():
-        api = Api(
-            apibp, title="EMAnnotationSchemas API", version=__version__, doc="/doc"
-        )
-        api.add_namespace(api_bp, path="/v2")
-        app.register_blueprint(apibp)
-        app.register_blueprint(views_bp)
-
-    return app
